searchData={"items":[{"type":"module","title":"SuperWorker","doc":"Documentation for `SuperWorker`.\n\nSuperWorker library is a open-source library for building a fault-tolerant,\ndistributed, and scalable Elixir applications contributed by Ohhi.vn\n\nSome of the features of SuperWorker include:\n- New Supervisor for Elxir application.","ref":"SuperWorker.html"},{"type":"module","title":"SuperWorker.Supervisor","doc":"Documentation for `SuperWorker.Supervisor`.\nThis module is a new model for the Supervisor module.\nSupervisor supports the following features:\n- Group processes\n- Chain processes\n- Freedom processes","ref":"SuperWorker.Supervisor.html"},{"type":"module","title":"Group processes - SuperWorker.Supervisor","doc":"Group processes are a set of processes that are started together. If one of the processes dies, all the processes in the group will be stopped.","ref":"SuperWorker.Supervisor.html#module-group-processes"},{"type":"module","title":"Chain processes - SuperWorker.Supervisor","doc":"Chain processes are a set of processes that are started one after another. The output of the previous process is passed to the next process.","ref":"SuperWorker.Supervisor.html#module-chain-processes"},{"type":"module","title":"Freedom processes - SuperWorker.Supervisor","doc":"Freedom processes are independent processes that are started separately.\n\nAll type of processes can be started in parallel & can be stopped individually or in a group.","ref":"SuperWorker.Supervisor.html#module-freedom-processes"},{"type":"module","title":"Examples - SuperWorker.Supervisor","doc":"# Start a supervisor with 2 partitions & 2 groups:\n  alias SuperWorker.Supervisor, as: Sup\n  opts = [id: :sup1, number_of_partitions: 2, link: false]\n  Sup.start(opts)\n\n  Sup.add_group(:sup1, [id: :group1, restart_strategy: :one_for_all])\n  Sup.add_group_worker(:sup1, :group1, {Dev, :task, [15]}, [id: :g1_1])\n\n  Sup.add_group(:sup1, [id: :group2, restart_strategy: :one_for_all])\n  Sup.add_group_worker(:sup1, :group2, fn ->\n    receice do\n    msg ->\n      :ok\n    end\n  end, [id: :g2_2])","ref":"SuperWorker.Supervisor.html#module-examples"},{"type":"function","title":"SuperWorker.Supervisor.add_chain/3","doc":"Add a chain to the supervisor.\nChain's options follow docs in `Chain` module.","ref":"SuperWorker.Supervisor.html#add_chain/3"},{"type":"function","title":"SuperWorker.Supervisor.add_chain_worker/5","doc":"Add a worker to the chain in supervisor.","ref":"SuperWorker.Supervisor.html#add_chain_worker/5"},{"type":"function","title":"SuperWorker.Supervisor.add_group/3","doc":"Add a group to the supervisor.\nGroup's options follow docs in `Group` module.","ref":"SuperWorker.Supervisor.html#add_group/3"},{"type":"function","title":"SuperWorker.Supervisor.add_group_worker/5","doc":"Add a  worker to a group in the supervisor.\nFunction's options follow `Worker` module.","ref":"SuperWorker.Supervisor.html#add_group_worker/5"},{"type":"function","title":"SuperWorker.Supervisor.add_standalone_worker/4","doc":"Add a standalone worker process to the supervisor.\nfunction for start worker can be a function or a {module, function, arguments}.\nStandalone worker is run independently from other workers follow :one_to_one strategy.\nIf worker crashes, it will check the restart strategy of worker then act accordingly.","ref":"SuperWorker.Supervisor.html#add_standalone_worker/4"},{"type":"function","title":"SuperWorker.Supervisor.broadcast_to_group/4","doc":"Send data to all workers in a group.","ref":"SuperWorker.Supervisor.html#broadcast_to_group/4"},{"type":"function","title":"SuperWorker.Supervisor.broadcast_to_my_group/1","doc":"Send data to all workers in current group of worker.\nUsing for communite between workers in the same group.","ref":"SuperWorker.Supervisor.html#broadcast_to_my_group/1"},{"type":"function","title":"SuperWorker.Supervisor.child_spec/1","doc":"","ref":"SuperWorker.Supervisor.html#child_spec/1"},{"type":"function","title":"SuperWorker.Supervisor.get_chain/3","doc":"","ref":"SuperWorker.Supervisor.html#get_chain/3"},{"type":"function","title":"SuperWorker.Supervisor.get_group/3","doc":"get group structure from supervisor.","ref":"SuperWorker.Supervisor.html#get_group/3"},{"type":"function","title":"SuperWorker.Supervisor.get_host_partition/2","doc":"","ref":"SuperWorker.Supervisor.html#get_host_partition/2"},{"type":"function","title":"SuperWorker.Supervisor.get_my_group/0","doc":"","ref":"SuperWorker.Supervisor.html#get_my_group/0"},{"type":"function","title":"SuperWorker.Supervisor.get_my_supervisor/0","doc":"","ref":"SuperWorker.Supervisor.html#get_my_supervisor/0"},{"type":"function","title":"SuperWorker.Supervisor.init/2","doc":"","ref":"SuperWorker.Supervisor.html#init/2"},{"type":"function","title":"SuperWorker.Supervisor.is_running?/1","doc":"Check if supervisor is running.\nreturn true if supervisor is running, otherwise return false.","ref":"SuperWorker.Supervisor.html#is_running?/1"},{"type":"function","title":"SuperWorker.Supervisor.main_loop/2","doc":"","ref":"SuperWorker.Supervisor.html#main_loop/2"},{"type":"function","title":"SuperWorker.Supervisor.remove_group_worker/4","doc":"","ref":"SuperWorker.Supervisor.html#remove_group_worker/4"},{"type":"function","title":"SuperWorker.Supervisor.send_to_chain/4","doc":"Send data to the entry worker in the chain.\nIf chain doesn't has any worker, it will be dropped.","ref":"SuperWorker.Supervisor.html#send_to_chain/4"},{"type":"function","title":"SuperWorker.Supervisor.send_to_group/5","doc":"Send data to a worker in the group.","ref":"SuperWorker.Supervisor.html#send_to_group/5"},{"type":"function","title":"SuperWorker.Supervisor.send_to_group_random/4","doc":"Send data to a random worker in the group.","ref":"SuperWorker.Supervisor.html#send_to_group_random/4"},{"type":"function","title":"SuperWorker.Supervisor.send_to_my_group/2","doc":"Send data to other worker in the same group.","ref":"SuperWorker.Supervisor.html#send_to_my_group/2"},{"type":"function","title":"SuperWorker.Supervisor.send_to_my_group_random/1","doc":"","ref":"SuperWorker.Supervisor.html#send_to_my_group_random/1"},{"type":"function","title":"SuperWorker.Supervisor.send_to_worker/4","doc":"Send data directly to the worker (standalone, group, chain) in the supervisor.","ref":"SuperWorker.Supervisor.html#send_to_worker/4"},{"type":"function","title":"SuperWorker.Supervisor.start/2","doc":"Start supervisor for run standalone please set option :link to false.\nresult format: {:ok, pid} or {:error, reason}","ref":"SuperWorker.Supervisor.html#start/2"},{"type":"function","title":"SuperWorker.Supervisor.stop/3","doc":"Stop supervisor.\nType of shutdown:\n- :normal supervisor will send a message to worker for graceful shutdown. Not support for spawn process by function.\n- :kill supervisor will kill worker.","ref":"SuperWorker.Supervisor.html#stop/3"},{"type":"module","title":"SuperWorker.Supervisor.Chain","doc":"Documentation for `SuperWorker.Supervisor.Chain`.","ref":"SuperWorker.Supervisor.Chain.html"},{"type":"function","title":"SuperWorker.Supervisor.Chain.add_worker/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#add_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Chain.check_options/1","doc":"","ref":"SuperWorker.Supervisor.Chain.html#check_options/1"},{"type":"function","title":"SuperWorker.Supervisor.Chain.get_all_workers/1","doc":"","ref":"SuperWorker.Supervisor.Chain.html#get_all_workers/1"},{"type":"function","title":"SuperWorker.Supervisor.Chain.get_worker/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#get_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Chain.kill_all_workers/1","doc":"","ref":"SuperWorker.Supervisor.Chain.html#kill_all_workers/1"},{"type":"function","title":"SuperWorker.Supervisor.Chain.kill_worker/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#kill_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Chain.new_data/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#new_data/2"},{"type":"function","title":"SuperWorker.Supervisor.Chain.remove_worker/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#remove_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Chain.restart_all_workers/1","doc":"","ref":"SuperWorker.Supervisor.Chain.html#restart_all_workers/1"},{"type":"function","title":"SuperWorker.Supervisor.Chain.restart_worker/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#restart_worker/2"},{"type":"type","title":"SuperWorker.Supervisor.Chain.t/0","doc":"","ref":"SuperWorker.Supervisor.Chain.html#t:t/0"},{"type":"function","title":"SuperWorker.Supervisor.Chain.worker_exists?/2","doc":"","ref":"SuperWorker.Supervisor.Chain.html#worker_exists?/2"},{"type":"module","title":"SuperWorker.Supervisor.ConfigWrapper","doc":"This module is a wrapper for the configuration of the supervisor.","ref":"SuperWorker.Supervisor.ConfigWrapper.html"},{"type":"function","title":"SuperWorker.Supervisor.ConfigWrapper.load/0","doc":"","ref":"SuperWorker.Supervisor.ConfigWrapper.html#load/0"},{"type":"function","title":"SuperWorker.Supervisor.ConfigWrapper.load/1","doc":"","ref":"SuperWorker.Supervisor.ConfigWrapper.html#load/1"},{"type":"function","title":"SuperWorker.Supervisor.ConfigWrapper.load_one/1","doc":"","ref":"SuperWorker.Supervisor.ConfigWrapper.html#load_one/1"},{"type":"module","title":"SuperWorker.Supervisor.Group","doc":"Documentation for `SuperWorker.Supervisor.Group`.","ref":"SuperWorker.Supervisor.Group.html"},{"type":"function","title":"SuperWorker.Supervisor.Group.add_worker/2","doc":"A internal function. Add a worker to the group.","ref":"SuperWorker.Supervisor.Group.html#add_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Group.broadcast/2","doc":"","ref":"SuperWorker.Supervisor.Group.html#broadcast/2"},{"type":"function","title":"SuperWorker.Supervisor.Group.check_options/1","doc":"Check, validate and convert key-value pairs to struct.","ref":"SuperWorker.Supervisor.Group.html#check_options/1"},{"type":"function","title":"SuperWorker.Supervisor.Group.get_all_workers/1","doc":"Get all workers from the group.","ref":"SuperWorker.Supervisor.Group.html#get_all_workers/1"},{"type":"function","title":"SuperWorker.Supervisor.Group.get_worker/2","doc":"Get worker from the group.","ref":"SuperWorker.Supervisor.Group.html#get_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Group.kill_all_workers/2","doc":"","ref":"SuperWorker.Supervisor.Group.html#kill_all_workers/2"},{"type":"function","title":"SuperWorker.Supervisor.Group.kill_worker/3","doc":"","ref":"SuperWorker.Supervisor.Group.html#kill_worker/3"},{"type":"function","title":"SuperWorker.Supervisor.Group.remove_worker/2","doc":"","ref":"SuperWorker.Supervisor.Group.html#remove_worker/2"},{"type":"function","title":"SuperWorker.Supervisor.Group.restart_worker/2","doc":"A internal function. Restart a worker in the group.","ref":"SuperWorker.Supervisor.Group.html#restart_worker/2"},{"type":"type","title":"SuperWorker.Supervisor.Group.t/0","doc":"","ref":"SuperWorker.Supervisor.Group.html#t:t/0"},{"type":"function","title":"SuperWorker.Supervisor.Group.worker_exists?/2","doc":"Check if worker exists in the group.","ref":"SuperWorker.Supervisor.Group.html#worker_exists?/2"},{"type":"module","title":"SuperWorker.Supervisor.MapQueue","doc":"","ref":"SuperWorker.Supervisor.MapQueue.html"},{"type":"function","title":"SuperWorker.Supervisor.MapQueue.add/2","doc":"","ref":"SuperWorker.Supervisor.MapQueue.html#add/2"},{"type":"function","title":"SuperWorker.Supervisor.MapQueue.get/2","doc":"","ref":"SuperWorker.Supervisor.MapQueue.html#get/2"},{"type":"function","title":"SuperWorker.Supervisor.MapQueue.is_full?/1","doc":"","ref":"SuperWorker.Supervisor.MapQueue.html#is_full?/1"},{"type":"function","title":"SuperWorker.Supervisor.MapQueue.new/1","doc":"","ref":"SuperWorker.Supervisor.MapQueue.html#new/1"},{"type":"function","title":"SuperWorker.Supervisor.MapQueue.remove/2","doc":"","ref":"SuperWorker.Supervisor.MapQueue.html#remove/2"},{"type":"module","title":"SuperWorker.Supervisor.Worker","doc":"Documentation for `SuperWorker.Supervisor.Worker`.","ref":"SuperWorker.Supervisor.Worker.html"},{"type":"function","title":"SuperWorker.Supervisor.Worker.check_chain_options/1","doc":"","ref":"SuperWorker.Supervisor.Worker.html#check_chain_options/1"},{"type":"function","title":"SuperWorker.Supervisor.Worker.check_group_options/1","doc":"","ref":"SuperWorker.Supervisor.Worker.html#check_group_options/1"},{"type":"function","title":"SuperWorker.Supervisor.Worker.check_standalone_options/1","doc":"","ref":"SuperWorker.Supervisor.Worker.html#check_standalone_options/1"},{"type":"function","title":"SuperWorker.Supervisor.Worker.get/2","doc":"","ref":"SuperWorker.Supervisor.Worker.html#get/2"},{"type":"function","title":"SuperWorker.Supervisor.Worker.remove/2","doc":"","ref":"SuperWorker.Supervisor.Worker.html#remove/2"},{"type":"function","title":"SuperWorker.Supervisor.Worker.save/1","doc":"","ref":"SuperWorker.Supervisor.Worker.html#save/1"},{"type":"type","title":"SuperWorker.Supervisor.Worker.t/0","doc":"","ref":"SuperWorker.Supervisor.Worker.html#t:t/0"},{"type":"function","title":"SuperWorker.Supervisor.Worker.update_process/4","doc":"","ref":"SuperWorker.Supervisor.Worker.html#update_process/4"},{"type":"function","title":"SuperWorker.Supervisor.Worker.update_process/5","doc":"","ref":"SuperWorker.Supervisor.Worker.html#update_process/5"},{"type":"module","title":"SuperWorker.TermStorage","doc":"A wrapper module for storing terms in :persistent_term.\nGood choice for storing data that is rarely change.\nData is can acessed by all processes in the same node.\n\nKey was prefixed with the module name to avoid key collision.\n\nNote:\nBy default, TermStorage will be limited to 1GB of memory.\nIf you need to store more data, you can increase the limit by setting the `:persistent_term` option in the Erlang VM.","ref":"SuperWorker.TermStorage.html"},{"type":"function","title":"SuperWorker.TermStorage.delete/1","doc":"Delete the key from the storage.","ref":"SuperWorker.TermStorage.html#delete/1"},{"type":"function","title":"SuperWorker.TermStorage.get/1","doc":"Get the value of the key from the storage.","ref":"SuperWorker.TermStorage.html#get/1"},{"type":"function","title":"SuperWorker.TermStorage.get_all/0","doc":"Get all key/value in the storage.","ref":"SuperWorker.TermStorage.html#get_all/0"},{"type":"function","title":"SuperWorker.TermStorage.put/2","doc":"Put the value of the key to the storage.","ref":"SuperWorker.TermStorage.html#put/2"},{"type":"behaviour","title":"SuperWorker.Worker","doc":"","ref":"SuperWorker.Worker.html"},{"type":"callback","title":"SuperWorker.Worker.error/2","doc":"","ref":"SuperWorker.Worker.html#c:error/2"},{"type":"callback","title":"SuperWorker.Worker.init/1","doc":"","ref":"SuperWorker.Worker.html#c:init/1"},{"type":"callback","title":"SuperWorker.Worker.spec/1","doc":"","ref":"SuperWorker.Worker.html#c:spec/1"},{"type":"callback","title":"SuperWorker.Worker.start/2","doc":"","ref":"SuperWorker.Worker.html#c:start/2"},{"type":"callback","title":"SuperWorker.Worker.start_link/2","doc":"","ref":"SuperWorker.Worker.html#c:start_link/2"},{"type":"callback","title":"SuperWorker.Worker.terminate/2","doc":"","ref":"SuperWorker.Worker.html#c:terminate/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}